@@ -68,13 +68,13 @@ static inline FunctionListElement * addFunctionListElement(FunctionListElement *
 											 unsigned int * inputGenes,
 											 unsigned int * transitionFunction)
 {
-	FunctionListElement * el = calloc(1,sizeof(FunctionListElement));
+	FunctionListElement * el = CALLOC(1,sizeof(FunctionListElement));
 	el->k = k;
 
-	el->inputGenes = calloc(k,sizeof(unsigned int));
+	el->inputGenes = CALLOC(k,sizeof(unsigned int));
 	memcpy(el->inputGenes,inputGenes,sizeof(unsigned int) * k);
 
-	el->transitionFunction = calloc(transitionFunctionSize,sizeof(unsigned int));
+	el->transitionFunction = CALLOC(transitionFunctionSize,sizeof(unsigned int));
 	memcpy(el->transitionFunction,transitionFunction,sizeof(unsigned int) * transitionFunctionSize);
 
 	el->next = *root;
@@ -93,9 +93,9 @@ void freeFunctionList(FunctionListElement ** root)
 	do
 	{
 		FunctionListElement * next = current->next;
-		free(current->inputGenes);
-		free(current->transitionFunction);
-		free(current);
+		FREE(current->inputGenes);
+		FREE(current->transitionFunction);
+		FREE(current);
 		current = next;
 	}
 	while(current != NULL);
@@ -114,11 +114,11 @@ static inline FunctionStackElement * pushFunctionStackElement(FunctionStackEleme
 											 unsigned int transitionFunctionSize,
 											 unsigned int pos)
 {
-	FunctionStackElement * el = calloc(1,sizeof(FunctionStackElement));
+	FunctionStackElement * el = CALLOC(1,sizeof(FunctionStackElement));
 
 	el->pos = pos;
 
-	el->transitionFunction = calloc(transitionFunctionSize,sizeof(unsigned int));
+	el->transitionFunction = CALLOC(transitionFunctionSize,sizeof(unsigned int));
 	memcpy(el->transitionFunction,transitionFunction,sizeof(unsigned int) * transitionFunctionSize);
 
 	el->next = *stack;
@@ -133,8 +133,8 @@ static inline void deleteFunctionStackElement(FunctionStackElement ** stack)
 {
 	FunctionStackElement * el = *stack;
 	*stack = (*stack)->next;
-	free(el->transitionFunction);
-	free(el);
+	FREE(el->transitionFunction);
+	FREE(el);
 }
 
 
@@ -279,7 +279,7 @@ void bestFitExtension(unsigned int * inputStates, unsigned int * outputStates,
 
 			// calculate the number of array elements needed
 			// to represent the output of a function
-			unsigned int array_sz = 1 << k;
+			unsigned int array_sz = (unsigned int)1 << k;
 			unsigned int numEltsFunc;
 			if (array_sz % BITS_PER_BLOCK_32 == 0)
 				numEltsFunc = array_sz / BITS_PER_BLOCK_32;
@@ -291,6 +291,8 @@ void bestFitExtension(unsigned int * inputStates, unsigned int * outputStates,
 
 			do
 			{
+  			R_CheckUserInterrupt();
+			
 				memset(c_0,0,sizeof(unsigned int) * array_sz);
 				memset(c_1,0,sizeof(unsigned int) * array_sz);
 
@@ -357,6 +359,8 @@ void bestFitExtension(unsigned int * inputStates, unsigned int * outputStates,
 					pushFunctionStackElement(&stack,f,numEltsFunc,0);
 					do
 					{
+					  R_CheckUserInterrupt();
+					  
 						// get top-level stack element
 						FunctionStackElement * el = stack;
 
@@ -379,7 +383,7 @@ void bestFitExtension(unsigned int * inputStates, unsigned int * outputStates,
 							// create a new element on the stack with the <pos>-th bit set to 1
 							FunctionStackElement * new = pushFunctionStackElement(&stack,el->transitionFunction,
 																				  numEltsFunc,el->pos+1);
-							new->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= 1 << (el->pos % BITS_PER_BLOCK_32);
+							new->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= (unsigned int)1 << (el->pos % BITS_PER_BLOCK_32);
 
 							// increment the position of the old element, which remains on the stack
 							// with the <pos>-th bit set to 0 (due to initialization)
@@ -391,7 +395,7 @@ void bestFitExtension(unsigned int * inputStates, unsigned int * outputStates,
 						{
 							// set the <pos>-th bit of the top-level stack element to 1,
 							// and increment the position to be examined
-							el->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= 1 << (el->pos % BITS_PER_BLOCK_32);
+							el->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= (unsigned int)1 << (el->pos % BITS_PER_BLOCK_32);
 							++el->pos;
 						}
 						else
@@ -431,7 +435,7 @@ static inline double entropy(unsigned int * inputStates, unsigned int * outputSt
 				      unsigned int numChosenIndices,
 				      unsigned int * table)
 {
-	unsigned int numEntries = 1 << numChosenIndices;
+	unsigned int numEntries = (unsigned int)1 << numChosenIndices;
 
 	// reset table to 0
 	memset(table,0,sizeof(unsigned int) * numEntries);
@@ -549,7 +553,7 @@ void reveal(unsigned int * inputStates, unsigned int * outputStates,
 
 			// calculate the number of array elements needed
 			// to represent the output of a function
-			unsigned int array_sz = 1 << k;
+			unsigned int array_sz = (unsigned int)1 << k;
 			unsigned int numEltsFunc;
 			if (array_sz % BITS_PER_BLOCK_32 == 0)
 				numEltsFunc = array_sz / BITS_PER_BLOCK_32;
@@ -559,7 +563,8 @@ void reveal(unsigned int * inputStates, unsigned int * outputStates,
 
 			do
 			{
-
+        R_CheckUserInterrupt();
+        
 				// calculate entropy of input genes
 				unsigned int table_input[array_sz];
 				double entropy_input = entropy(inputStates, outputStates, numStates,
@@ -569,7 +574,7 @@ void reveal(unsigned int * inputStates, unsigned int * outputStates,
 				unsigned int comb_output[k+1];
 				memcpy(comb_output,comb,sizeof(unsigned int) * k);
 				comb_output[k] = numGenes + i;
-				unsigned int table_output[1 << (k+1)];
+				unsigned int table_output[(unsigned int)1 << (k+1)];
 
 				double entropy_all = entropy(inputStates, outputStates, numStates,
 											 numElts, numGenes, comb_output, k+1, table_output);
@@ -592,6 +597,8 @@ void reveal(unsigned int * inputStates, unsigned int * outputStates,
 					pushFunctionStackElement(&stack,f,numEltsFunc,0);
 					do
 					{
+					  R_CheckUserInterrupt();
+					
 						// get top-level stack element
 						FunctionStackElement * el = stack;
 
@@ -606,7 +613,7 @@ void reveal(unsigned int * inputStates, unsigned int * outputStates,
 							deleteFunctionStackElement(&stack);
 						}
 						else
-						if (table_input[el->pos] == 0 || table_output[el->pos | (1 << k)] == table_output[el->pos])
+						if (table_input[el->pos] == 0 || table_output[el->pos | ((unsigned int)1 << k)] == table_output[el->pos])
 						// no information is available if the <pos>-th bit must be set to one or zero
 						// => create two solution branches, one with the <pos>-th bit set to 1
 						// and one with the <pos>-th bit set to 0
@@ -614,19 +621,19 @@ void reveal(unsigned int * inputStates, unsigned int * outputStates,
 							// create a new element on the stack with the <pos>-th bit set to 1
 							FunctionStackElement * new = pushFunctionStackElement(&stack,el->transitionFunction,
 																				  numEltsFunc,el->pos+1);
-							new->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= 1 << (el->pos % BITS_PER_BLOCK_32);
+							new->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= (unsigned int)1 << (el->pos % BITS_PER_BLOCK_32);
 
 							// increment the position of the old element, which remains on the stack
 							// with the <pos>-th bit set to 0 (due to initialization)
 							++el->pos;
 						}
 						else
-						if (table_output[el->pos | (1 << k)] > table_output[el->pos])
+						if (table_output[el->pos | ((unsigned int)1 << k)] > table_output[el->pos])
 						// the <pos>-th bit must be set to 1
 						{
 							// set the <pos>-th bit of the top-level stack element to 1,
 							// and increment the position to be examined
-							el->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= 1 << (el->pos % BITS_PER_BLOCK_32);
+							el->transitionFunction[el->pos / BITS_PER_BLOCK_32] |= (unsigned int)1 << (el->pos % BITS_PER_BLOCK_32);
 							++el->pos;
 						}
 						else
@@ -699,8 +706,8 @@ SEXP reconstructNetwork_R(SEXP inputStates, SEXP outputStates, SEXP numberOfStat
 				(_outputStates[state*numGenes + gene] << (gene % BITS_PER_BLOCK_32));
 	}
 
-	FunctionListElement ** res = calloc(numGenes,sizeof(FunctionListElement *));
-	unsigned int * errors = calloc(numGenes,sizeof(unsigned int));
+	FunctionListElement ** res = CALLOC(numGenes,sizeof(FunctionListElement *));
+	unsigned int * errors = CALLOC(numGenes,sizeof(unsigned int));
 
 	if (_method == 0)
 		// perform Lähdesmäki's best-fit extension
@@ -771,7 +778,7 @@ SEXP reconstructNetwork_R(SEXP inputStates, SEXP outputStates, SEXP numberOfStat
 			}
 			else
 			{
-				numBits = 1 << cur->k;
+				numBits = (unsigned int)1 << cur->k;
 				for (j = 0; j < cur->k; j++)
 					array[j] = cur->inputGenes[cur->k - j - 1] + 1;
 			}
@@ -806,8 +813,8 @@ SEXP reconstructNetwork_R(SEXP inputStates, SEXP outputStates, SEXP numberOfStat
 	// free resources
 	for (gene = 0; gene < numGenes; ++gene)
 		freeFunctionList(&res[gene]);
-	free(errors);
-	free(res);
+	FREE(errors);
+	FREE(res);
 
 	return resSXP;
 }
